@@ -1,5 +1,5 @@
 /* combine - flexible file merging    
-   Copyright (C) 2002, 2003 Daniel P. Valentine
+   Copyright (C) 2002, 2003 Free Software Foundation, Inc.
 
    This file was written by Daniel P. Valentine <dpv@world.std.com>
 
@@ -17,4 +17,5 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-STRINGTYPE* df_get_next_record(FILE*, unsigned char**, size_t*, size_t*, STRINGTYPE*, size_t);
+STRINGTYPE *df_get_next_record (FILE *, unsigned char **, size_t *, size_t *,
+				STRINGTYPE *, size_t);
